@@ -53,9 +53,9 @@ struct _EosTimeSyncPluginPrivate {
 HD_DEFINE_PLUGIN (EosTimeSyncPlugin, eos_time_sync_plugin, HILDON_DESKTOP_TYPE_HOME_ITEM);
 
 /* forward declarations */
-static gboolean ntp_clicked(GtkWidget *widget, GdkEventButton *button, gpointer data);
-static gboolean usb_clicked(GtkWidget *widget, GdkEventButton *button, gpointer data);
-static gboolean eos_clicked(GtkWidget *widget, GdkEventButton *button, gpointer data);
+static gboolean ntp_clicked(GtkWidget *widget, gpointer data);
+static gboolean usb_clicked(GtkWidget *widget, gpointer data);
+static gboolean eos_clicked(GtkWidget *widget, gpointer data);
 static int usb_mode_get();
 static int usb_mode_toggle();
 static void eos_time_sync_save_preferences (EosTimeSyncPlugin *home_plugin);
@@ -206,7 +206,7 @@ eos_time_sync_settings(HildonDesktopHomeItem   *applet,
 	GtkWidget *item;
 
 #ifdef __i386__	
-	printf("settings\n");
+	printf("eos_time_sync_settings - enter\n");
 #endif
 	item = gtk_menu_item_new_with_label ("Eos Time Sync");
 
@@ -232,6 +232,9 @@ eos_time_sync_plugin_destroy (GtkObject *object)
     g_object_unref (priv->gconf_client);
     priv->gconf_client = NULL;
   }
+#ifdef __i386__	
+  printf("eos_time_sync_plugin_destroy - leave\n");
+#endif
 }
 
 static void
@@ -424,12 +427,18 @@ eos_time_sync_plugin_init (EosTimeSyncPlugin *home_plugin)
   if (! priv->usb_enabled) gtk_widget_hide (usb_button);
   if (! priv->camera_enabled) gtk_widget_hide (eos_button);
 
+#ifdef __i386__	
+  printf("eos_time_sync_plugin_init - ntp_server: %s\n", priv->ntp_server);
+  printf("priv: %x\n", priv);
+  printf("home_plugin->priv: %x\n", home_plugin->priv);
+  printf("home_plugin: %x\n", home_plugin);
+#endif
   g_signal_connect(G_OBJECT(ntp_button), "clicked",
-		   G_CALLBACK(ntp_clicked), home_plugin);
+		   G_CALLBACK(ntp_clicked), (gpointer)home_plugin);
   g_signal_connect(G_OBJECT(usb_button), "clicked",
-		   G_CALLBACK(usb_clicked), home_plugin);
+		   G_CALLBACK(usb_clicked), (gpointer)home_plugin);
   g_signal_connect(G_OBJECT(eos_button), "clicked",
-		   G_CALLBACK(eos_clicked), home_plugin);
+		   G_CALLBACK(eos_clicked), (gpointer)home_plugin);
  
   
 }
@@ -516,10 +525,10 @@ static int usb_mode_toggle()
  * @param widget the button widget
  * @param data helloworld info struct
  */
-static gboolean ntp_clicked(GtkWidget *widget, GdkEventButton *button,
-                            gpointer data)
+static gboolean ntp_clicked(GtkWidget *widget, gpointer data)
 {
-    EosTimeSyncPluginPrivate *priv = data;  
+    EosTimeSyncPlugin *home_plugin = EOSTIMESYNC_PLUGIN(data);  
+    EosTimeSyncPluginPrivate *priv = home_plugin->priv;
     char cmd[255];
     char buf[1024];
     int retval;
@@ -527,9 +536,17 @@ static gboolean ntp_clicked(GtkWidget *widget, GdkEventButton *button,
     GtkWidget *dialog;
 
     hildon_banner_show_information(NULL, NULL, "Setting the time via NTP");
+#ifdef __i386__	
+    printf("data: %x \n", data);
+    printf("priv: %x \n", priv);
+#endif
     
     //strcpy(cmd, NTP_COMMAND);
     snprintf(cmd, 255, NTP_COMMAND, priv->ntp_server);
+#ifdef __i386__	
+    printf("eos_time_sync_ntp_clicked - ntp_server: %s\n", priv->ntp_server);
+    printf("eos_time_sync_ntp_clicked - cmd: %s\n", cmd);
+#endif
     handle = popen (cmd, "r");
     if (!handle) {
         hildon_banner_show_information(NULL, NULL, "ntp: popen failed");
@@ -606,8 +623,7 @@ static gboolean ntp_clicked(GtkWidget *widget, GdkEventButton *button,
  * @param widget the button widget
  * @param data helloworld info struct
  */
-static gboolean usb_clicked(GtkWidget *widget, GdkEventButton *button,
-                            gpointer data)
+static gboolean usb_clicked(GtkWidget *widget, gpointer data)
 {
     char filename[15];
     
@@ -629,8 +645,7 @@ static gboolean usb_clicked(GtkWidget *widget, GdkEventButton *button,
  * @param widget the button widget
  * @param data helloworld info struct
  */
-static gboolean eos_clicked(GtkWidget *widget, GdkEventButton *button,
-                            gpointer data)
+static gboolean eos_clicked(GtkWidget *widget, gpointer data)
 {
     char cmd[255];
     char buf[1024];
